@@ -79,3 +79,5 @@
 #define WALLET_RPC_ERROR_CODE_ZERO_AMOUNT            -46
 #define WALLET_RPC_ERROR_CODE_INVALID_SIGNATURE_TYPE -47
 #define WALLET_RPC_ERROR_CODE_DISABLED               -48
+#define WALLET_RPC_ERROR_CODE_PROXY_ALREADY_DEFINED  -49
+#define WALLET_RPC_ERROR_CODE_NONZERO_UNLOCK_TIME    -50
