@@ -158,6 +158,17 @@ TEST(DNSResolver, GetTXTRecord)
   EXPECT_STREQ("donate.getmonero.org", addr.c_str());
 }
 
+TEST(DNSResolver, Localhost)
+{
+  tools::DNSResolver resolver = tools::DNSResolver::create();
+
+  bool avail, valid;
+  std::vector<std::string> ips = resolver.get_ipv4("localhost", avail, valid);
+
+  ASSERT_EQ(1, ips.size());
+  ASSERT_EQ("127.0.0.1", ips[0]);
+}
+
 bool is_equal(const char *s, const std::vector<std::string> &v) { return v.size() == 1 && v[0] == s; }
 
 TEST(DNS_PUBLIC, empty) { EXPECT_TRUE(tools::dns_utils::parse_dns_public("").empty()); }
